Documentation
¶
Index ¶
- Variables
- func Database(err error, msg ...string) error
- func DbFilterNoMoreRows(err error) error
- func DbPrettyNoMoreRows(err error, msg string) error
- func Network(err error, msg ...string) error
- func New(msg string) error
- func Redis(err error, msg ...string) error
- func System(err error, msg ...string) error
- func Wrap(err error, msg ...string) error
- type CodeError
- type Frame
- type StackTrace
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func DbFilterNoMoreRows ¶
DbFilterNoMoreRows 过滤sql.ErrNoRows错误
func DbPrettyNoMoreRows ¶
DbPrettyNoMoreRows 优化查无记录的错误 调用方无需额外判断是否为空记录,只需要指定遇到空记录时,替换的错误提示
Types ¶
type CodeError ¶
func (CodeError) StackTrace ¶
func (s CodeError) StackTrace() StackTrace
type Frame ¶
type Frame uintptr
Frame represents a program counter inside a stack frame. For historical reasons if Frame is interpreted as a uintptr its value represents the program counter + 1.
func (Frame) Format ¶
Format formats the frame according to the fmt.Formatter interface.
%s source file %d source line %n function name %v equivalent to %s:%d
Format accepts flags that alter the printing of some verbs, as follows:
%+s function name and path of source file relative to the compile time
GOPATH separated by \n\t (<funcname>\n\t<path>)
%+v equivalent to %+s:%d
func (Frame) MarshalText ¶
MarshalText formats a stacktrace Frame as a text string. The output is the same as that of fmt.Sprintf("%+v", f), but without newlines or tabs.
type StackTrace ¶
type StackTrace []Frame
StackTrace is stack of Frames from innermost (newest) to outermost (oldest).
func (StackTrace) Format ¶
func (st StackTrace) Format(s fmt.State, verb rune)
Format formats the stack of Frames according to the fmt.Formatter interface.
%s lists source files for each Frame in the stack %v lists the source file and line number for each Frame in the stack
Format accepts flags that alter the printing of some verbs, as follows:
%+v Prints filename, function, and line number for each Frame in the stack.